@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '5.20240829';
+$CPAN::Perl::Releases::VERSION = '5.20241020';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -310,6 +310,8 @@ our $data =
 "5.41.1" => { id => 'BOOK' },
 "5.41.2" => { id => 'ETHER' },
 "5.41.3" => { id => 'BOOK' },
+"5.41.4" => { id => 'CONTRA' },
+"5.41.5" => { id => 'HYDAHY' },
 };
 
 sub perl_tarballs {
@@ -379,7 +381,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 5.20240829
+version 5.20241020
 
 =head1 SYNOPSIS
 
